Crate aristech_stt_client

Crate aristech_stt_client 

Aristech STT-Client

The Aristech STT-Client is a client library for the Aristech STT-Server.

Modules

stt_service
The stt_service module contains types and functions generated from the Aristech STT proto file.

Structs

Auth
The Auth struct holds the token and secret needed to authenticate with the server.
AuthInterceptor
The AuthInterceptor struct is used to intercept requests to the server and add the authentication headers.
SttClientBuilder
The SttClientBuilder struct is used to build a SttClient with the given host and tls options.
TlsOptions
The TlsOptions struct holds the tls options needed to communicate with the server.

Functions

get_account_info
Gets the account information from the server.
get_client
Creates a new SttClient to communicate with the server.
get_models
Gets the list of available models from the server.
get_nlp_functions
Gets the list of available NLP functions for each configured NLP-Server.
nlp_process
Processes the given text with a given NLP pipeline using the STT-Server as proxy.
recognize_file
Performs speech recognition on a wav file

Type Aliases

SttClient
The SttClient type is a type alias for the SttServiceClient with the AuthInterceptor.