Aristech STT-Client
The Aristech STT-Client is a client library for the Aristech STT-Server.
Modules
- stt_
service - The stt_service module contains types and functions generated from the Aristech STT proto file.
Structs
- Auth
- The Auth struct holds the token and secret needed to authenticate with the server.
- Auth
Interceptor - The AuthInterceptor struct is used to intercept requests to the server and add the authentication headers.
- SttClient
Builder - The SttClientBuilder struct is used to build a SttClient with the given host and tls options.
- TlsOptions
- The TlsOptions struct holds the tls options needed to communicate with the server.
Functions
- get_
account_ info - Gets the account information from the server.
- get_
client - Creates a new SttClient to communicate with the server.
- get_
models - Gets the list of available models from the server.
- get_
nlp_ functions - Gets the list of available NLP functions for each configured NLP-Server.
- nlp_
process - Processes the given text with a given NLP pipeline using the STT-Server as proxy.
- recognize_
file - Performs speech recognition on a wav file
Type Aliases
- SttClient
- The SttClient type is a type alias for the SttServiceClient with the AuthInterceptor.